%define         anolis_release 1

Name:           oath-toolkit
Version:        2.6.12
Release:        %{anolis_release}%{?dist}
Summary:        One-time password components

License:        GPLv3+
URL:            https://www.nongnu.org/oath-toolkit/
Source0:        https://download.savannah.nongnu.org/releases/%{name}/%{name}-%{version}.tar.gz
Patch0:         0001-oath-toolkit-2.6.7-lockfile.patch

BuildRequires:  make
BuildRequires:  pam-devel
BuildRequires:  gtk-doc
BuildRequires:  libtool
BuildRequires:  libtool-ltdl-devel
BuildRequires:  xmlsec1-devel
BuildRequires:  xmlsec1-openssl-devel
BuildRequires:  autoconf
BuildRequires:  automake

%description
OATH Toolkit provide components to build one-time password authentication systems.
It contains shared C libraries, command line tools and a PAM module.
Supported technologies include the event-based HOTP algorithm (RFC 4226),
the time-based TOTP algorithm (RFC 6238), and Portable Symmetric Key Container (PSKC, RFC 6030)
to manage secret key data. OATH stands for Open AuTHentication,
which is the organization that specify the algorithms.

%package -n liboath
Summary:        Library for OATH handling
License:        LGPLv2+
Provides:       bundled(gnulib)
 
%description -n liboath
OATH stands for Open AuTHentication, which is the organization that
specify the algorithms. Supported technologies include the event-based
HOTP algorithm (RFC4226) and the time-based TOTP algorithm (RFC6238).

%package -n liboath-devel
Summary:        Development files for liboath
License:        LGPLv2+
Requires:       liboath = %{version}-%{release}
 
%description -n liboath-devel
Development files for liboath.

%package -n liboath-doc
Summary:        Documentation files for liboath
License:        LGPLv2+
Requires:       liboath = %{version}-%{release}
Requires:       gtk-doc
BuildArch:      noarch
 
%description -n liboath-doc
Documentation files for liboath.
 
%package -n libpskc
Summary:        Library for PSKC handling
License:        LGPLv2+
Requires:       xml-common
Provides:       bundled(gnulib)
 
%description -n libpskc
Library for managing secret key files, the Portable Symmetric Key
Container (PSKC) format described in RFC6030 is supported.
 
%package -n libpskc-devel
Summary:       Development files for libpskc
License:       LGPLv2+
Requires:      libpskc = %{version}-%{release}
 
%description -n libpskc-devel
Development files for libpskc.


%package -n libpskc-doc
Summary:        Documentation files for libpskc
License:        LGPLv2+
Requires:       libpskc = %{version}-%{release}
Requires:       gtk-doc
BuildArch:      noarch
 
%description -n libpskc-doc
Documentation files for libpskc.

%package -n oathtool
Summary:        A command line tool for generating and validating OTPs
License:        GPLv3+
Provides:       bundled(gnulib)
 
%description -n oathtool
A command line tool for generating and validating OTPs.
 
%package -n pskctool
Summary:        A command line tool for manipulating PSKC data
Provides:       bundled(gnulib)
Requires:       xmlsec1-openssl
 
%description -n pskctool
A command line tool for manipulating PSKC data.
 
%package -n pam_oath
Summary:        A PAM module for pluggable login authentication for OATH
Requires:       pam
 
%description -n pam_oath
A PAM module for pluggable login authentication for OATH.

%prep
%setup -q
%patch0 -p1 -b .lockfile

%build
autoreconf -fi
%configure --with-pam-dir=%{_libdir}/security
 
# Kill rpaths and link with --as-needed
for d in liboath libpskc pskctool oathtool pam_oath
do
  sed -i 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' $d/libtool
  sed -i 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' $d/libtool
  sed -i 's| -shared | -Wl,--as-needed\0|g' $d/libtool
done
 
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install
 
# Remove static objects and libtool files
rm -f %{buildroot}%{_libdir}/*.{a,la}
rm -f %{buildroot}%{_libdir}/security/*.la
 
# Make /etc/liboath directory
mkdir -p -m 0600 %{buildroot}%{_sysconfdir}/liboath
 
%ldconfig_scriptlets -n liboath
 
%ldconfig_scriptlets -n libpskc

%generate_compatibility_deps

%files -n liboath
%doc liboath/COPYING
%attr(0600, root, root) %dir %{_sysconfdir}/liboath
%{_libdir}/liboath.so.*
%dir %{abidir}
%{abidir}/liboath.dump
 
%files -n liboath-devel
%{_includedir}/liboath
%{_libdir}/liboath.so
%{_libdir}/pkgconfig/liboath.pc
 
%files -n liboath-doc
%{_mandir}/man3/oath*
%{_datadir}/gtk-doc/html/liboath/*
 
%files -n libpskc
%doc libpskc/README
%{_libdir}/libpskc.so.*
%{_datadir}/xml/pskc
%{abidir}/libpskc.dump
 
%files -n libpskc-devel
%{_includedir}/pskc
%{_libdir}/libpskc.so
%{_libdir}/pkgconfig/libpskc.pc
 
%files -n libpskc-doc
%{_mandir}/man3/pskc*
%{_datadir}/gtk-doc/html/libpskc/*
 
%files -n oathtool
%doc oathtool/COPYING
%{_bindir}/oathtool
%{abidir}/oathtool-option.list
%{_mandir}/man1/oathtool.*
 
%files -n pskctool
%{_bindir}/pskctool
%{abidir}/pskctool-option.list
%{_mandir}/man1/pskctool.*
 
%files -n pam_oath
%doc pam_oath/README pam_oath/COPYING
%{_libdir}/security/pam_oath.so
%{abidir}/pam_oath.dump

%changelog
* Mon Nov 18 2024 tingyin duan <tingyin.duan@qq.com>  - 2.6.12-1
- update to version 2.6.12

* Mon Mar 27 2023 Feng Su <sufeng@linux.alibaba.com>  - 2.6.7-1
- package init from upstream
